==> haskell-openpgp-asciiarmor-0.1.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-CIwgy5cLf6fK8raSqOoJDt
key: openpgp-asciiarmor-0.1.1-CIwgy5cLf6fK8raSqOoJDt
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 974d93821196f2601655b654bfea58b5
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-CIwgy5cLf6fK8raSqOoJDt
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    base64-bytestring-1.0.0.2-Exy4D7U0AzaE8TUydrgSTP binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-B2amXpZsUqgLdkg0t6RH2y
key: openpgp-asciiarmor-0.1.1-B2amXpZsUqgLdkg0t6RH2y
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 213978879ffe6d5b86e975a1266adb48
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-B2amXpZsUqgLdkg0t6RH2y
depends:
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70 binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
